import { Editor } from './../index';
import { Animation, EditMode, PasteFormat, ToolbarViewMode, EditorDataExport, EditorIframeSettings, ToolbarItem } from './../index';
import { AfterViewInit, ElementRef, OnInit, OnChanges, OnDestroy, SimpleChanges, EventEmitter } from '@angular/core';
import { BaseElement } from './smart.element';
export { Animation, EditMode, PasteFormat, ToolbarViewMode, EditorDataExport, EditorIframeSettings, ToolbarItem, ToolbarItemEditor, ElementRenderMode } from './../index';
export { Smart } from './smart.element';
export { Editor } from './../index';
export declare class EditorComponent extends BaseElement implements OnInit, AfterViewInit, OnDestroy, OnChanges {
    constructor(ref: ElementRef<Editor>);
    private eventHandlers;
    nativeElement: Editor;
    /** @description Creates the component on demand.
     * @param properties An optional object of properties, which will be added to the template binded ones.
     */
    createComponent(properties?: {}): any;
    /** @description Sets or gets the animation mode. Animation is disabled when the property is set to 'none' */
    animation: Animation;
    /** @description Automatically loads the last saved state of the editor (from local storage) on element initialization. An id must be provided in order to load a previously saved state. */
    autoLoad: boolean;
    /** @description Automatically saves the current content of the editor. Saving happens at time intervas determined by the autoSaveInterval property while the element on focus. An id must be provided to the element in order to store the state. */
    autoSave: boolean;
    /** @description The interval that determines the interval to automatically save the state of the Editor when the autoSave property is set. */
    autoSaveInterval: boolean;
    /** @description A formatting function for the char counter. Takes two arguments: chars - the current number of characters inside the Editor.maxCharCount - the maximum number of characters inside the Editor. */
    chartCountFormatFunction: any;
    /** @description Sets the Editor's Data Export options. */
    dataExport: EditorDataExport;
    /** @description Enables or disables the Editor. */
    disabled: boolean;
    /** @description Disables content editing inside Editor. */
    disableEditing: boolean;
    /** @description Determines the edit mode for the Editor. By default the editor's content accepts and parses HTML. However if set to 'markdown' the Editor can be used as a full time Markdown Editor by parsing the makrdown to HTML in preview mode. */
    editMode: EditMode;
    /** @description Determines whether the HTML returned from the value property or displayed by Preview mode is encoded or not */
    enableHtmlEncode: boolean;
    /** @description Determines whether the Tab key can insert tab chars inside the Editor or change focus (default) */
    enableTabKey: boolean;
    /** @description Determines whether the Toolbar is hidden or not. */
    hideToolbar: boolean;
    /** @description Determines whether the Inline Toolbar is hidden or not. */
    hideInlineToolbar: boolean;
    /** @description Sets the content of the Editor. Similar to value property allows to set the content of the editor. */
    innerHTML: string;
    /** @description Defines an offset(x,y) for the Inline Toolbar positioning on the page. */
    inlineToolbarOffset: number[];
    /** @description Determines the iframe settings of the Editor. When enabled the contents of the Editor are placed inside an iframe, isolated in a separate dom. The element allows to insert external resources into the iframe if needed. */
    iframeSettings: EditorIframeSettings;
    /** @description Determines the format of the content that will be pasted inside the Editor. */
    pasteFormat: PasteFormat;
    /** @description Sets or gets the language. Used in conjunction with the property messages.  */
    locale: string;
    /** @description Sets a limit on the number of chars inside the Editor.  */
    maxCharCount: number;
    /** @description Sets or gets an object specifying strings used in the widget that can be localized. Used in conjunction with the property language.  */
    messages: any;
    /** @description Determines the placeholder that will be shown when there's no content inside the Editor. */
    placeholder: string;
    /** @description Determines whether the value is sanitized from XSS content or not. When enabled scripts and other XSS vulnerabilities are not allowed to exist inside the Editor's as HTML content. */
    sanitized: boolean;
    /** @description Determines whether the char counter is visible or not. When enabled it is displayed in the bottom right corner. If maxCharCount is set and the content characters are equal or more than 70% of the maximum char count the counter is colored in order to warn the user. If the char count is equal or more than 90% the counter is again colored with a different warning color to indicate that the counter is near maximum. When maximum is reached, text input is not allowed. */
    showCharCount: boolean;
    /** @description Determines the refresh interval for the Source Code/Preview Panel when Split Mode is enabled.  */
    splitModeRefreshTimeout: number;
    /** @description Determines the theme. Theme defines the look of the element */
    theme: string;
    /** @description Determines the Toolbar items list. Each item can be string pointing to the name of the item or an object that defines a custom item or adds aditional settings to an item. The name of the items are case insensitive. An object definition should contain a name attribute that refers to the name of the item when modifing an existing toolbar item. The name attribute determines the action of the item. If set to 'custom' it is possible to create a custom toolbar item. If name attribute is not set or not valid it is treated as a separator, no a toolbar item. The following items are supported by default by the Editor: SourceCode - shows the HTML/Preview Panel by hiding the input panel. Item type - 'Toggle button'.SplitMode - shows both input and HTML/Preview Panel by splitting the Editor content in two sections. Item type - 'Toggle button'FullScreen - fits the viewport with the Editor by expanding it over the page content. Item type - 'Toggle button'.Alignment - aligns the selected content. Item type - 'Drop down'.FontName - changes the font family of the selected content. Item type - 'drop-down'.FontSize - changes the font size of the selected content. Item type - 'drop-down'.Formats - changes the format of the current selection. Itme type - 'drop-down'.TableRows - allows to insert/remove a row into a selected table element. Item type - 'drop-down'.TableColumns - allows to insert/remove a column into a selected table element. Itme type - 'drop-down'.TableVAlign - sets the vertical alignment of a selected table cell. Item type - 'drop-down'.TableStyle - sets additional styling to a selected table inside the Editor. Item type - 'drop-down'.BackgroundColor - changes the background color of the current selection. Item type - 'color-input'.FontColor - changes the font color of the current selection. Item type = 'color-input'.Bold - sets the currently selected text as bold or not. Item type - 'button'.Italic - sets the currently selected text as italic. Item type - 'button'. Underline - sets the currently selected text as underlined. Itme type - 'button'.Strikethrough - set the currently selected text as strikethrough. Item type - 'button'.Delete - deletes the current selection. Item type - 'button'.Undo - undoes the last operation. Item type - 'button'.Redo - redoes the previous operation. Item type - 'button'.Indent - indents the current selection once. Item type - 'button'.Outdent - outdents the current selection once. Item type - 'button'.OpenLink - triggers a hyperlink. Item type - 'button'.EditLink - creates/edits the selected hyperlink. Item type - 'button'.CreateLink - creates/edits the selected hyperlink. Item type - 'button'.RemoveLink - removes the currently selected hyperlink. Item type - 'button'.Hyperlink - same as createLink, triggers a Dialog Window for link creation. Item type - 'button'.Cut - Cuts the currently selected text. Item type - 'button'.Copy - copies the currently selected text. Item type - 'button'Paste - pastes the currenly copied/cut text from the Clipboard. Item type = 'button' or 'drop-down' when advanced attribute is set to 'true'.Image - triggers a Dialog Window to insert/edit an image. Item type - 'button'.LowerCase - changes the current selection to lower case. Item type - 'button'.UpperCase - changes the current selection to upper case. Item type - 'button'.Print - opens the browser print preview window. Item type - 'button'.Caption - insert/remove a caption when a table is selected. Item type - 'button'.ClearFormat - removes the formatting of the currntly selected text. Item type - 'button'.Table - triggers a Dialog Window to insert a table. Item type - 'button'.TableHeader - insert/remove a header row to the currently selected table. Item type - 'button'.OrderedList - insert/remove an order list. Item type = 'button'.UnorderedList - insert/remove an unordered list. Item type - 'button'.Subscript - changes the currently selected text to subscript. Item type - 'button'.Superscript - changes the currently selected text to superscript. Item type - 'button'.  The inlineToolbarItems attribute is applicable only to the following items: 'table', 'image', 'hyperlink'. It accepts the same type of value as toolbarItems property but the toolbar items will be placed insinde the Inline Toolbar instead. */
    toolbarItems: ToolbarItem[];
    /** @description Determines the format of the content that will be pasted inside the Editor. */
    toolbarViewMode: ToolbarViewMode;
    /** @description Sticks the Toolbar to the top of the window and stays there while scrolling. */
    toolbarSticky: boolean;
    /** @description If is set to true, the element cannot be focused. */
    unfocusable: boolean;
    /** @description Sets or gets the value of the Editor. */
    value: string;
    /** @description This event is triggered on blur if the content is changed.
    *  @param event. The custom event. 	*/
    onChange: EventEmitter<CustomEvent>;
    /** @description This event is triggered before a Toolbar action is started. The event can be canceled via event.preventDefault().
    *  @param event. The custom event. 	*/
    onActionStart: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a Toolbar action has ended.
    *  @param event. The custom event. 	*/
    onActionEnd: EventEmitter<CustomEvent>;
    /** @description This event is triggered when an image/table resizing has started.
    *  @param event. The custom event. 	*/
    onResizeStart: EventEmitter<CustomEvent>;
    /** @description This event is triggered when an image/table resizing has ended.
    *  @param event. The custom event. 	*/
    onResizeEnd: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the inline Toolbar is opened.
    *  @param event. The custom event. 	*/
    onInlineToolbarOpen: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the inline Toolbar is closed.
    *  @param event. The custom event. 	*/
    onInlineToolbarClose: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the Drop Down Toolbar is opened.
    *  @param event. The custom event. 	*/
    onDropDownToolbarOpen: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the Drop Down Toolbar is closed.
    *  @param event. The custom event. 	*/
    onDropDownToolbarClose: EventEmitter<CustomEvent>;
    /** @description This event is triggered the Dialog Window is opened.
    *  @param event. The custom event. 	*/
    onDialogOpen: EventEmitter<CustomEvent>;
    /** @description This event is triggered before the Dialog Window is opened. The event can be prevented via event.preventDefault().
    *  @param event. The custom event. 	*/
    onDialogOpening: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the Dialog Window is closed.
    *  @param event. The custom event. 	*/
    onDialogClose: EventEmitter<CustomEvent>;
    /** @description This event is triggered before the Dialog Window is closed. The event can be prevented via event.preventDefault().
    *  @param event. The custom event. 	*/
    onDialogClosing: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the uploading of an image is successful.
    *  @param event. The custom event. 	*/
    onImageUploadSuccess: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the uploading of an image is unsuccessful.
    *  @param event. The custom event. 	*/
    onImageUploadFailed: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a Toolbar item is clicked.
    *  @param event. The custom event. 	*/
    onToobarItemClick: EventEmitter<CustomEvent>;
    /** @description Blurs the content of the Editor.
    */
    blur(): void;
    /** @description Clears the content of the Editor.
    */
    clearContent(): void;
    /** @description Collapse the Toolbar if the toolbarViewMode is set to 'toggle'.
    */
    collapseToolbar(): void;
    /** @description Disables a Toolbar item.
    * @param {string} itemName. The name of the toolbar item to disable.
    */
    disableToolbarItem(itemName: string): void;
    /** @description Expand the Toolbar if the toolbarViewMode is set to 'toggle'.
    */
    expandToolbar(): void;
    /** @description Enables a previously disabled Toolbar item.
    * @param {string} itemName. The name of the toolbar item to enable.
    */
    enableToolbarItem(itemName: string): void;
    /** @description Executes a command via the native execCommand method. The method returns true or false depending on whether the execution was successful or not.
    * @param {string} commandName. The name of the command to execute.
    * @param {string | number} value?. The value for the command. Some commands require a value to be passed, others do not.
    * @returns {boolean}
  */
    executeCommand(commandName: any, value?: any): Promise<any>;
    /** @description Focuses the content of the Editor.
    */
    focus(): void;
    /** @description Returns the number of characters inside the Editor's content.
    * @returns {number}
  */
    getCharCount(): Promise<any>;
    /** @description Returns the current selection range. By default the result is an object of type Range, but if the editMode property is set to 'markdown' the returned value is an object indicating the start/end indexes of the current selection.
    * @returns {any}
  */
    getSelectionRange(): Promise<any>;
    /** @description Selects the text inside Editor's content.
    */
    selectAll(): void;
    /** @description Returns the content of the Editor as HTML. When editMode is set to 'markdown' the markdown is parsed and returned as HTML.
    * @returns {string}
  */
    getHTML(): Promise<any>;
    /** @description Returns the content of the Editor as text.
    * @returns {string}
  */
    getText(): Promise<any>;
    /** @description Applicable only when editMode is set to 'markdown'. Returns the Editor's content as markdown.
    * @returns {string}
  */
    getMarkdown(): Promise<any>;
    /** @description Selects a range of text inside the Editor.
    * @param {HTMLElement | Node} node. The node to be selected. It can be a text node or an HTML element.
    * @param {number} startIndex?. The start index of the node to select from. If not provided all node contents are selected.
    * @param {number} endIndex?. The end index of the node to select to. If not provided all node contents are selected.
    */
    selectRange(node: HTMLElement | Node, startIndex?: number, endIndex?: number): void;
    /** @description Clears the local storage from previously stored states of the Editor with the current id.
    */
    clearState(): void;
    /** @description Saves the current state of the Editor to local storage. Requires an id to be set to the Editor.
    */
    saveState(): void;
    /** @description Loads the last stored state of the Editor from local storage. Requires an id to be set to the Editor.
    */
    loadState(): void;
    /** @description Sets Editor into Split Mode. In split mode the HTML/Markdown editor and SourceCode/Preview panels are visible.
    * @param {boolean} value?. Determines whether to enter or leave split mode. By default the argument is not passed and the mode is toggled.
    */
    splitMode(value?: boolean): void;
    /** @description Sets Editor into SourceCode/Preview Mode. In this mode the HTML view panel is displayed.
    * @param {boolean} value?. Determines whether to enter or leave split mode. By default the argument is not passed and the mode is toggled.
    */
    previewMode(value?: boolean): void;
    /** @description Sets Editor into Full Screen Mode. If enabled the Editor is positioned above the page content and fills the screen.
    * @param {boolean} value?. Determines whether to enter or leave split mode. By default the argument is not passed and the mode is toggled.
    */
    fullScreenMode(value?: boolean): void;
    /** @description Exports the content of the Editor in the desired format. The currently supported formats are: HTML, Markdown.
    * @param {string} dataFormat. The expected file format.
    * @param {any} callback?. A callback that is executed before the data is exported. Allows to modify the output.
    */
    exportData(dataFormat: string, callback?: any): void;
    /** @description Opens the Print Preview Panel of the Browser to print Editor's content.
    */
    print(): void;
    readonly isRendered: boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** @description Add event listeners. */
    private listen;
    /** @description Remove event listeners. */
    private unlisten;
}
